Oh hello


Install
-------

`harper` uses `pyalsaaudio` under the hood and therefore requires
some alsa dependencies to run. On ubuntu, this is addressed
by running
`sudo apt-get -y install libasound2-dev`

then run
`pip install harper`